/* $Id$
   
   Copyright (C) 2018-2021 Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 0.8.0 (2021-07-14)
   Website: http://www.gingerblue.org/
   
*/

#include <libxml/xmlmemory.h>
#include <libxml/parser.h>

GingerblueData *gb_file_config_load (GingerblueData *head, gchar *filename);

static void gb_file_parse_volume (GingerblueData *data, xmlDocPtr doc, xmlNodePtr cur);

