/* $Id$
   
   Copyright (C) 2018-2021 Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 0.8.0 (2021-07-14)
   Website: http://www.gingerblue.org/
   
*/

GtkAssistantPageFunc gb_assistant_cb (GtkAssistant *assistant, GDateTime *datestamp);
